pub struct Icmpv4Packet {
pub typ: u8,
pub code: u8,
pub checksum: u16,
pub message: Icmpv4Message,
}Expand description
An Icmpv4 Packet.
Fields
typ: u8code: u8checksum: u16message: Icmpv4MessageImplementations
Sourceimpl Icmpv4Packet
impl Icmpv4Packet
Sourcepub fn parse<B: AsRef<[u8]>>(bytes: B) -> Result<Self, PacketParseError>
pub fn parse<B: AsRef<[u8]>>(bytes: B) -> Result<Self, PacketParseError>
Parse an Icmpv4Packet from bytes including the IPv4 header.
Sourcepub fn get_bytes(&self, with_checksum: bool) -> Vec<u8> ⓘ
pub fn get_bytes(&self, with_checksum: bool) -> Vec<u8> ⓘ
Get this packet serialized to bytes suitable for sending on the wire.
Sourcepub fn calculate_checksum(&self) -> u16
pub fn calculate_checksum(&self) -> u16
Calculate the checksum for the packet given the provided source and destination addresses.
Sourcepub fn with_checksum(self) -> Self
pub fn with_checksum(self) -> Self
Populate the checksum field of this Packet.