pub struct Icmpv6Packet {
pub typ: u8,
pub code: u8,
pub checksum: u16,
pub message: Icmpv6Message,
}Fields
typ: u8code: u8checksum: u16message: Icmpv6MessageImplementations
Sourceimpl Icmpv6Packet
impl Icmpv6Packet
Sourcepub fn parse<B: AsRef<[u8]>>(bytes: B) -> Result<Self, PacketParseError>
pub fn parse<B: AsRef<[u8]>>(bytes: B) -> Result<Self, PacketParseError>
Construct a packet by parsing the provided bytes.
Sourcepub fn get_bytes(&self, with_checksum: bool) -> Vec<u8> ⓘ
pub fn get_bytes(&self, with_checksum: bool) -> Vec<u8> ⓘ
Get this packet serialized to bytes suitable for sending on the wire.
Sourcepub fn calculate_checksum(&self, source: &Ipv6Addr, dest: &Ipv6Addr) -> u16
pub fn calculate_checksum(&self, source: &Ipv6Addr, dest: &Ipv6Addr) -> u16
Calculate the checksum for the packet given the provided source and destination addresses.
Sourcepub fn with_checksum(self, source: &Ipv6Addr, dest: &Ipv6Addr) -> Self
pub fn with_checksum(self, source: &Ipv6Addr, dest: &Ipv6Addr) -> Self
Fill the checksum for the packet using the given source and destination addresses.
Sourcepub fn with_packet_too_big(
mtu: u32,
packet: Vec<u8>,
) -> Result<Self, IcmpPacketBuildError>
pub fn with_packet_too_big( mtu: u32, packet: Vec<u8>, ) -> Result<Self, IcmpPacketBuildError>
Construct a packet for Packet Too Big messages.