IcmpSocket6

Struct IcmpSocket6 

pub struct IcmpSocket6 { /* private fields */ }
An Icmpv6 socket.

Implementations

Source

impl IcmpSocket6

pub fn new() -> Result<Self>

Construct a new raw socket. The socket must be bound to an address using bind_to before it can be used to send and receive packets.

pub fn new_dgram_socket() -> Result<Self>

Construct a new dgram socket. The socket must be bound to an address using bind_to before it can be used to send and receive packets.