pub struct IcmpSocket6 { /* private fields */ }Expand description
An Icmpv6 socket.
Implementations
Sourceimpl IcmpSocket6
impl IcmpSocket6
Sourcepub fn new() -> Result<Self>
pub fn new() -> Result<Self>
Construct a new raw socket. The socket must be bound to an address using bind_to
before it can be used to send and receive packets.
Sourcepub fn new_dgram_socket() -> Result<Self>
pub fn new_dgram_socket() -> Result<Self>
Construct a new dgram socket. The socket must be bound to an address using bind_to
before it can be used to send and receive packets.